@@ -51,7 +51,7 @@ pub mod pass;
 mod pos;
 mod rustc_data_structures;
 pub mod serializer;
-mod source_map;
+pub mod source_map;
 pub mod sync;
 mod syntax_pos;
 pub mod util;
